testdb

package
v0.0.0-...-d80aada Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package testdb provides test database utilities for integration tests.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetTestDB

func GetTestDB(t *testing.T) *pgxpool.Pool

GetTestDB returns a test database connection pool. It skips the test if no database is available.

Types

This section is empty.

Jump to